@@ -11,7 +11,6 @@ import System.Process
 import Control.Monad
 import System.Directory hiding (findFiles)
 import Data.Maybe (mapMaybe)
-import System.Directory (removeDirectoryRecursive)
 import System.FilePath ((</>))
 import qualified Codec.Archive.Tar as Tar
 import Control.Exception
@@ -73,10 +72,12 @@ keter cabal noBuild noCopyTo = do
         collapse' (x:xs) = x : collapse' xs
         collapse' [] = []
 
-    unless noBuild $ do
-        run cabal ["clean"]
-        run cabal ["configure"]
-        run cabal ["build"]
+    unless noBuild $ if elem "stack.yaml" files
+        then do run "stack" ["clean"]
+                createDirectoryIfMissing True "./dist/bin"
+                run "stack"
+                    (words "--local-bin-path ./dist/bin build --copy-bins")
+        else mapM_ (\x -> run cabal [x]) ["clean", "configure", "build"]
 
     _ <- try' $ removeDirectoryRecursive "static/tmp"
 
