@@ -5,7 +5,9 @@ import           Control.Monad          (unless)
 import           Data.Monoid
 import           Data.Version           (showVersion)
 import           Options.Applicative
+import           System.Environment     (getEnvironment)
 import           System.Exit            (ExitCode (ExitSuccess), exitWith)
+import           System.FilePath        (splitSearchPath)
 import           System.Process         (rawSystem)
 
 import           AddHandler             (addHandler)
@@ -13,7 +15,7 @@ import           Devel                  (DevelOpts (..), devel, DevelTermOpt(..)
 import           Keter                  (keter)
 import           Options                (injectDefaults)
 import qualified Paths_yesod_bin
-import           Scaffolding.Scaffolder
+import           Scaffolding.Scaffolder (scaffold, backendOptions)
 
 import           HsFile                 (mkHsFile)
 #ifndef WINDOWS
@@ -41,7 +43,7 @@ data Options = Options
                }
   deriving (Show, Eq)
 
-data Command = Init { _initBare :: Bool }
+data Command = Init { _initBare :: Bool, _initName :: Maybe String, _initDatabase :: Maybe String }
              | HsFiles
              | Configure
              | Build { buildExtraArgs   :: [String] }
@@ -99,7 +101,7 @@ main = do
          ] optParser'
   let cabal = rawSystem' (cabalCommand o)
   case optCommand o of
-    Init bare       -> scaffold bare
+    Init{..}        -> scaffold _initBare _initName _initDatabase
     HsFiles         -> mkHsFile
     Configure       -> cabal ["configure"]
     Build es        -> touch' >> cabal ("build":es)
@@ -108,7 +110,9 @@ main = do
     Version         -> putStrLn ("yesod-bin version: " ++ showVersion Paths_yesod_bin.version)
     AddHandler{..}  -> addHandler addHandlerRoute addHandlerPattern addHandlerMethods
     Test            -> cabalTest cabal
-    Devel{..}       -> let develOpts = DevelOpts
+    Devel{..}       ->do
+                       (configOpts, menv) <- handleGhcPackagePath
+                       let develOpts = DevelOpts
                              { isCabalDev   = optCabalPgm o == CabalDev
                              , forceCabal   = _develDisableApi
                              , verbose      = optVerbose o
@@ -121,14 +125,28 @@ main = do
                              , proxyTimeout = _proxyTimeout
                              , useReverseProxy = not _noReverseProxy
                              , terminateWith = if _interruptOnly then TerminateOnlyInterrupt else TerminateOnEnter
+                             , develConfigOpts = configOpts
+                             , develEnv = menv
                              }
-                       in devel develOpts develExtraArgs
+                       devel develOpts develExtraArgs
   where
     cabalTest cabal = do touch'
                          _ <- cabal ["configure", "--enable-tests", "-flibrary-only"]
                          _ <- cabal ["build"]
                          cabal ["test"]
 
+handleGhcPackagePath :: IO ([String], Maybe [(String, String)])
+handleGhcPackagePath = do
+    env <- getEnvironment
+    case lookup "GHC_PACKAGE_PATH" env of
+        Nothing -> return ([], Nothing)
+        Just gpp -> do
+            let opts = "--package-db=clear"
+                     : "--package-db=global"
+                     : map ("--package-db=" ++)
+                       (drop 1 $ reverse $ splitSearchPath gpp)
+            return (opts, Just $ filter (\(x, _) -> x /= "GHC_PACKAGE_PATH") env)
+
 optParser' :: ParserInfo Options
 optParser' = info (helper <*> optParser) ( fullDesc <> header "Yesod Web Framework command line utility" )
 
@@ -136,8 +154,7 @@ optParser :: Parser Options
 optParser = Options
         <$> flag Cabal CabalDev ( long "dev"     <> short 'd' <> help "use cabal-dev" )
         <*> switch              ( long "verbose" <> short 'v' <> help "More verbose output" )
-        <*> subparser ( command "init"
-                            (info (Init <$> (switch (long "bare" <> help "Create files in current folder")))
+        <*> subparser ( command "init"         (info initOptions
                             (progDesc "Scaffold a new site"))
                       <> command "hsfiles" (info (pure HsFiles)
                             (progDesc "Create a hsfiles file for the current folder"))
@@ -160,6 +177,14 @@ optParser = Options
                             (progDesc "Print the version of Yesod"))
                       )
 
+initOptions :: Parser Command
+initOptions = Init
+    <$> switch (long "bare" <> help "Create files in current folder")
+    <*> optStr (long "name" <> short 'n' <> metavar "APP_NAME"
+            <> help "Set the application name")
+    <*> optStr (long "database" <> short 'd' <> metavar "DATABASE"
+            <> help ("Preconfigure for selected database (options: " ++ backendOptions ++ ")"))
+
 keterOptions :: Parser Command
 keterOptions = Keter
     <$> switch ( long "nobuild" <> short 'n' <> help "Skip rebuilding" )
